@@ -519,8 +519,8 @@ cpl_error_code qmost_ffnorm_fib(
 
     /* Create a bad pixel mask for each fibre */
 
-    maxfirst = -1;
-    minlast = naxis[0];
+    maxfirst = 0;
+    minlast = naxis[0]-1;
     for (i = 0; i < naxis[1]; i++) {
         dat = datav + i*naxis[0];
         b = bpm + i*naxis[0];
@@ -532,10 +532,6 @@ cpl_error_code qmost_ffnorm_fib(
         if(j == naxis[0]) {
             bad_spec[i] = 1;
         }
-        if (!bad_spec[i] && !not_for_med[i]) {
-            maxfirst = qmost_max(maxfirst,qmost_firstgood(b,naxis[0]));
-            minlast = qmost_min(minlast,qmost_lastgood(b,naxis[0]));
-        }
     }
     qmost_sumbpm(bad_spec,(int)naxis[1],&j);
     allbad = (j == naxis[1]);
@@ -761,7 +757,7 @@ cpl_error_code qmost_ffnorm_fib(
 
             if(qmost_med(buf,NULL,n,&val) != CPL_ERROR_NONE) {
                 cpl_errorstate_set(prestate);
-                val = 0;
+                val = 1.0;
             }
 
             bb = pow(val,2.0);
