@@ -186,6 +186,12 @@ static cpl_error_code qmost_imcombine_skylevel (
  * @param   thresh           (Given)    The threshold level in terms
  *                                      of background noise for
  *                                      rejection.
+ * @param   checkexp         (Given)    If true, check median count
+ *                                      level on image.
+ * @param   underexp         (Given)    A minimum count level in ADU
+ *                                      to reject underexposed data.
+ * @param   overexp          (Given)    A maximum count level in ADU
+ *                                      to reject overexposed data.
  * @param   out_img          (Returned) The resulting combined image.
  * @param   out_var          (Returned) The corresponding variance
  *                                      array, or NULL if not needed.
@@ -248,6 +254,9 @@ cpl_error_code qmost_imcombine_lite (
     int fibre,
     int xrej,
     float thresh,
+    int checkexp,
+    float underexp,
+    float overexp,
     cpl_image **out_img,
     cpl_image **out_var,
     cpl_propertylist *out_hdr)
@@ -419,6 +428,23 @@ cpl_error_code qmost_imcombine_lite (
                                          ifile+1);
         }
 
+        /* Check exposure if we're doing that */
+        if(checkexp) {
+            if(skylevel < underexp || skylevel >= overexp) {
+                cpl_msg_warning(cpl_func,
+                                "File %d median counts/pixel = %.0f, BAD",
+                                ifile+1,
+                                skylevel);
+                continue;
+            }
+            else {
+                cpl_msg_debug(cpl_func,
+                              "File %d median counts/pixel = %.0f, OK",
+                              ifile+1,
+                              skylevel);
+            }
+        }
+
         /* Scale by exposure time if we're doing that */
         if(scaletype == 3) {
             skylevel *= ff->expadj;
@@ -482,6 +508,13 @@ cpl_error_code qmost_imcombine_lite (
         }
     }
 
+    if(ngood <= 0) {
+        TIDY;
+        return cpl_error_set_message(cpl_func,
+                                     CPL_ERROR_DATA_NOT_FOUND,
+                                     "there were no good exposures");
+    }
+
     /* Create output */
     *out_img = cpl_image_new(fileptrs[0].nx, fileptrs[0].ny, CPL_TYPE_FLOAT);
     if(*out_img == NULL) {
