@@ -499,7 +499,7 @@ static int qmost_dark_combine(
                                      "time");
     }
     
-    if(exptime < 0) {
+    if(exptime < 1.0) {
         exptime = 1.0;
     }
 
