@@ -172,6 +172,10 @@ cpl_recipe_define(qmost_detector_flat_analyse,
  *   - @b gaincor.window (int, default 16)
  *     Measurement window size of the strip at the adjacent edges of
  *     the amplifiers to use for gain correction.
+ *   - @b detflat.underexp (float, default 5000)
+ *     The flux limit in ADU to define an underexposed image.
+ *   - @b detflat.overexp (float, default 60000)
+ *     The flux limit in ADU to define an overexposed image.
  *   - @b detflat.medfil (int, default 25)
  *     Window size of 2D median filter used to remove the LED
  *     illumination pattern.
@@ -380,6 +384,8 @@ static int qmost_detector_flat_analyse(
     int xrej = 0;
     double combthresh = 5.0;
     int stripsize = 16;
+    double underexp = 5000.0;
+    double overexp = 60000.0;
     int medfil = 25;
     int linfil = 5;
     int ncells = 256;
@@ -538,6 +544,16 @@ static int qmost_detector_flat_analyse(
         stripsize = cpl_parameter_get_int(par);
 
     /* Retrieve detflat parameters */
+    par = cpl_parameterlist_find_const(parlist,
+                                       RECIPE_NAME".detflat.underexp");
+    if(par != NULL)
+        underexp = cpl_parameter_get_double(par);
+
+    par = cpl_parameterlist_find_const(parlist,
+                                       RECIPE_NAME".detflat.overexp");
+    if(par != NULL)
+        overexp = cpl_parameter_get_double(par);
+
     par = cpl_parameterlist_find_const(parlist,
                                        RECIPE_NAME".detflat.medfil");
     if(par != NULL)
@@ -851,6 +867,9 @@ static int qmost_detector_flat_analyse(
                                      0,
                                      xrej,
                                      combthresh,
+                                     1,  /* check exposure */
+                                     underexp,
+                                     overexp,
                                      &detflat_img,
                                      &detflat_var,
                                      qclist) != CPL_ERROR_NONE) {
@@ -1145,6 +1164,30 @@ static cpl_error_code qmost_detector_flat_analyse_fill_parameterlist(
     cpl_parameterlist_append(self, par);
 
     /* Detector flat parameters */
+    par = cpl_parameter_new_value(RECIPE_NAME".detflat.underexp",
+                                  CPL_TYPE_DOUBLE,
+                                  "A minimum count level in ADU to be "
+                                  "used to reject underexposed flats.",
+                                  RECIPE_NAME,
+                                  5000.0);
+    cpl_parameter_set_alias(par,
+                            CPL_PARAMETER_MODE_CLI,
+                            "detflat.underexp");
+    cpl_parameter_disable(par, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(self, par);
+
+    par = cpl_parameter_new_value(RECIPE_NAME".detflat.overexp",
+                                  CPL_TYPE_DOUBLE,
+                                  "A saturation level in ADU to be "
+                                  "used to reject overexposed flats.",
+                                  RECIPE_NAME,
+                                  60000.0);
+    cpl_parameter_set_alias(par,
+                            CPL_PARAMETER_MODE_CLI,
+                            "detflat.overexp");
+    cpl_parameter_disable(par, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(self, par);
+
     par = cpl_parameter_new_value(RECIPE_NAME".detflat.medfil",
                                   CPL_TYPE_INT,
                                   "2D median filter window size used "
