@@ -991,6 +991,9 @@ static int qmost_fpe_analyse(
                                      1,  /* fibre spectra */
                                      xrej,
                                      combthresh,
+                                     0,
+                                     0.0,
+                                     0.0,
                                      &arc_img,
                                      &arc_var,
                                      qclist) != CPL_ERROR_NONE) {
