@@ -914,6 +914,9 @@ static int qmost_psf_analyse(
                                      1,  /* fibre spectra */
                                      xrej,
                                      combthresh,
+                                     0,
+                                     0.0,
+                                     0.0,
                                      &fibre_flat_img,
                                      &fibre_flat_var,
                                      qclist) != CPL_ERROR_NONE) {
