@@ -1082,6 +1082,9 @@ static int qmost_trace(
                                      1,  /* fibre spectra */
                                      xrej,
                                      combthresh,
+                                     0,
+                                     0.0,
+                                     0.0,
                                      &fibre_flat_img,
                                      &fibre_flat_var,
                                      qclist) != CPL_ERROR_NONE) {
