@@ -61,17 +61,16 @@ raw_detector_flat_lin_ds = (
   .with_min_group_size(5)
   .build())
 
-# Raw daytime spectroscopic calibration frames.  These are still
-# grouped by setup as above so we don't mix readout settings when
-# stacking the inputs, but when they are used they are matched on
-# spectrograph only, so the results are used to process any binning
-# setting (these calibration frames are universal).
+# Raw daytime spectroscopic calibration frames.  Setup includes full
+# detector (det.binx, det.biny, det.read.curid) like BIAS; match rules
+# use instrume_spectro so calibrations match on spectrograph only and
+# binned science data can still find matching calibration frames.
 
 raw_fibre_flat_day_ds = (
   data_source("FIBRE_FLAT_DAY")
   .with_classification_rule(raw_fibre_flat_day_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=ONE_WEEK,
                        level=0)   # calibration plan
@@ -84,7 +83,7 @@ raw_fibre_wave_simuarc_ds = (
   data_source("FIBRE_WAVE_SIMUARC")
   .with_classification_rule(raw_fibre_wave_simuarc_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=ONE_MONTH,
                        level=0)   # calibration plan
@@ -97,7 +96,7 @@ raw_fibre_wave_simufpe_ds = (
   data_source("FIBRE_WAVE_SIMUFPE")
   .with_classification_rule(raw_fibre_wave_simufpe_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=ONE_MONTH,
                        level=0)   # calibration plan
@@ -110,7 +109,7 @@ raw_fibre_wave_day_ds = (
   data_source("FIBRE_WAVE_DAY")
   .with_classification_rule(raw_fibre_wave_day_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=ONE_DAY,
                        level=0)   # calibration plan
@@ -129,7 +128,7 @@ raw_fibre_flat_sky_ds = (
   data_source("FIBRE_FLAT_SKY")
   .with_classification_rule(raw_fibre_flat_sky_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=ONE_WEEK,
                        level=0)   # calibration plan
@@ -145,7 +144,7 @@ raw_fibre_flat_night_ds = (
   data_source("FIBRE_FLAT_NIGHT")
   .with_classification_rule(raw_fibre_flat_night_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=SAME_NIGHT,
                        level=0)   # calibration plan
@@ -158,7 +157,7 @@ raw_fibre_wave_night_ds = (
   data_source("FIBRE_WAVE_NIGHT")
   .with_classification_rule(raw_fibre_wave_night_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro,
                        time_range=SAME_NIGHT,
                        level=0)   # calibration plan
@@ -173,7 +172,7 @@ raw_science_ds = (
   data_source("OBJECT")
   .with_classification_rule(raw_science_class)
   .with_grouping_keywords([ kwd.tpl_start ] + kwd.instrume_setup)
-  .with_setup_keywords(kwd.spectro)
+  .with_setup_keywords(kwd.setup)
   .with_match_keywords(kwd.instrume_spectro)
   .build())
 
